//
// This file is part of the Marble Desktop Globe.
//
// This program is free software licensed under the GNU LGPL. You can
// find a copy of this license in LICENSE.txt in the top directory of
// the source code.
//
// Copyright 2008 Torsten Rahn <tackat@kde.org>"
//

#include "TestPlugin.h"

#include <QtGui/QColor>
#include <QtGui/QPixmap>
#include <QtGui/QRadialGradient>
#include <QTimer>

#include "MarbleDirs.h"
#include "MarbleWidget.h"
#include "MarbleMap.h"
#include "MarbleModel.h"

#include "GeoPainter.h"
#include "GeoDataCoordinates.h"
#include "GeoDataLineString.h"
#include "GeoDataLinearRing.h"

#include "ViewportParams.h"

#include "MapViewLayer.h"

namespace Marble
{

TestPlugin::TestPlugin()
: m_marbleWidget( 0 )
{
	m_pUpdateTimer = NULL;
	m_pUpdateTimer = new QTimer();
	m_pUpdateTimer->setSingleShot(true);
	m_pUpdateTimer->setInterval(500);
	connect( m_pUpdateTimer, SIGNAL(timeout()), SLOT(slotUpdateMap()) );

	m_iCount=0;
	m_pLayer=NULL;

}
TestPlugin::~TestPlugin()
{
	if(m_pUpdateTimer!=NULL)
		delete m_pUpdateTimer;
	if(m_pLayer!=NULL)
		delete m_pLayer;
	
}

void TestPlugin::slotUpdateMap()
{

	m_pUpdateTimer->stop();

	GeoDataLineString  lineString;
	GeoDataCoordinates pos;
	int i=0;
	qreal lon=11.0;
	qreal lat=47.0;
	pos.set(lon,lat,0,GeoDataCoordinates::Degree);
	lineString << pos;
	
	switch(m_iCount)
	{
		case 0:
			for(i=0;i<200;i++)
			{
				lon -= 0.1;
				lat += 0.1;
				pos.set(lon,lat,0,GeoDataCoordinates::Degree);
				lineString << pos;
			}
			m_iCount++;
			break;
		case 1:
			for(i=0;i<200;i++)
			{
				lat += 0.1;
				pos.set(lon,lat,0,GeoDataCoordinates::Degree);
				lineString << pos;
			}
			m_iCount++;	
			break;
		case 2:
			for(i=0;i<200;i++)
			{
				lon += 0.1;
				lat += 0.1;
				pos.set(lon,lat,0,GeoDataCoordinates::Degree);
				lineString << pos;
			}
			m_iCount=0;	
			break;
	}

	emit signalUpdatePoly(lineString);

	m_marbleWidget->repaint();

	m_pUpdateTimer->start();

}

QStringList TestPlugin::backendTypes() const
{
    return QStringList( "test" );
}

QString TestPlugin::renderPolicy() const
{
    return QString( "ALWAYS" );
}

QStringList TestPlugin::renderPosition() const
{
    return QStringList( "ALWAYS_ON_TOP" );
}

QString TestPlugin::name() const
{
    return tr( "Test Plugin" );
}

QString TestPlugin::guiString() const
{
    return tr( "&Test Plugin" );
}

QString TestPlugin::nameId() const
{
    return QString( "test-plugin" );
}

QString TestPlugin::description() const
{
    return tr( "This is a simple test plugin." );
}

QIcon TestPlugin::icon () const
{
    return QIcon();
}


void TestPlugin::initialize ()
{
	if(m_pLayer==NULL && m_marbleWidget!=NULL)
	{
		m_pLayer = new MapViewLayer(m_marbleWidget,m_marbleWidget->parentWidget(),0);
		if(m_pLayer==NULL)return;

		//pLayer->setModel(d->m_treeViewModel);

		m_marbleWidget->addLayer(m_pLayer);

	/*	connect( m_pLayer, SIGNAL( placemarkSelected( QModelIndex ) ),
				 this, SLOT( activatePlacemark( QModelIndex ) ) );
		connect( m_pLayer, SIGNAL( pointSelected( GeoDataCoordinates ) ),
				 this, SLOT( retrieveSelectedPoint( GeoDataCoordinates ) ) );
		connect( m_pLayer, SIGNAL( pointSelectionAborted() ),
				 this, SLOT( pointSelectionCanceled() ) );*/

		connect(this,SIGNAL(signalUpdatePoly(GeoDataLineString&) ),
				m_pLayer, SLOT(slotUpdatePoly(GeoDataLineString&)) );

		m_pUpdateTimer->start();
	}

}

bool TestPlugin::isInitialized () const
{
    return (m_pLayer!=NULL);
}

bool TestPlugin::eventFilter(QObject *object, QEvent *e)
{
    if ( !enabled() || !visible() ) {
        return false;
    }

    MarbleWidget *widget = dynamic_cast<MarbleWidget*> (object);
	 if ( !widget ) {
        return RenderPlugin::eventFilter(object, e);
    }

	if ( m_marbleWidget != widget ) {
        // Delayed initialization
        m_marbleWidget = widget;
	}

	 return RenderPlugin::eventFilter(object, e);
}

bool TestPlugin::render( GeoPainter *painter, ViewportParams *viewport, const QString& renderPos, GeoSceneLayer * layer )
{
	Q_UNUSED( layer )

	if ( renderPos != "ALWAYS_ON_TOP" ) {
        return true;
    }

    painter->save();

    painter->autoMapQuality();

 
    return true;
}

}

Q_EXPORT_PLUGIN2( TestPlugin, Marble::TestPlugin )

#include "./temp/TestPlugin.moc"
