//
// This file is part of the Marble Desktop Globe.
//
// This program is free software licensed under the GNU LGPL. You can
// find a copy of this license in LICENSE.txt in the top directory of
// the source code.
//
// Copyright 2008 Torsten Rahn <tackat@kde.org>"
//

//
// This class is a test plugin.
//

#ifndef MARBLETESTPLUGIN_H
#define MARBLETESTPLUGIN_H

#include <QtCore/QObject>

#include "RenderPlugin.h"

class QTimer;

namespace Marble
{

	class MarbleWidget;
	class MapViewLayer;
	class GeoDataLineString;
	
/**
 * @short The class that specifies the Marble layer interface of a plugin.
 *
 */

class TestPlugin : public RenderPlugin
{
    Q_OBJECT
    Q_INTERFACES( Marble::RenderPluginInterface )
    MARBLE_PLUGIN( TestPlugin )

 public:

     explicit TestPlugin();
    ~TestPlugin();

    QStringList backendTypes() const;

    QString renderPolicy() const;

    QStringList renderPosition() const;

    QString name() const;

    QString guiString() const;

    QString nameId() const;

    QString description() const;

    QIcon icon () const;


    void initialize ();

    bool isInitialized () const;


    bool render( GeoPainter *painter, ViewportParams *viewport, const QString& renderPos, GeoSceneLayer * layer = 0 );

protected:
    bool eventFilter( QObject *object, QEvent *e );

private slots:
	void slotUpdateMap();

Q_SIGNALS:
	void signalUpdatePoly(GeoDataLineString&);

private:

	/** MarbleWidget this float item is installed as event filter for */
    MarbleWidget*	m_marbleWidget;
	QTimer*			m_pUpdateTimer;
	MapViewLayer*	m_pLayer;
	int				m_iCount;
};

}

#endif // MARBLETESTPLUGIN_H
